@@ -56,7 +56,7 @@ class MyBarLogger(ProgressBarLogger):
 
 
 def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, time_o=5):
-    if deezer_artist_id == 977996688:
+    if deezer_artist_id == 977996688 or deezer_artist_id == 96969996688:
         return None
     path_video = None
     try:
